# Changelog

## Version 2.0.0
- Improve properties reading using `nvme id-ctrl` instead of relying on `nvme fw-log`
- Rewrite using a properties object.
- Add -i flag to print information about the available drives.

**Full Changelog**: [v1.2.2...v2.0.0](https://github.com/not-a-feature/wd_fw_update/compare/v1.2.2...v2.0.0)

## Version 1.2.2
- Fix download url.
- Add http status code test.

**Full Changelog**: [v1.2.1...v1.2.2](https://github.com/not-a-feature/wd_fw_update/compare/v1.2.1...v1.2.2)

## Version 1.2.1
- Remove debug value

**Full Changelog**: [v1.1.1...v1.2.1](https://github.com/not-a-feature/wd_fw_update/compare/v1.2.0...v1.2.1)

## Version 1.2.0
- Perform version dependency check earlier s.t. it fails early.
- Improved error messages.
- Improved docstrings.

**Full Changelog**: [v1.1.1...v1.2.0](https://github.com/not-a-feature/wd_fw_update/compare/v1.1.1...v1.2.0)

## Version 1.1.1
- Improve nvme slot detection.
- Improve Readme and Output.
**Full Changelog**: [v1.1.0...v1.1.1](https://github.com/not-a-feature/wd_fw_update/compare/v1.1.0...v1.1.1)

## Version 1.1.0
- Improve nvme slot detection.
- Remove python 3.12 exclusive feature.
- Fix whitespace issue in logo.

**Full Changelog**: [v1.0.1...v1.1.0](https://github.com/not-a-feature/wd_fw_update/compare/v1.0.1...v1.1.0)

## Version 1.0.1
- Add message and improve docs.

**Full Changelog**: [v1.0.0...v1.0.1](https://github.com/not-a-feature/wd_fw_update/compare/v1.0.0...v1.0.1)

## Version 1.0.0 (initial release)

- Initial release
